@@ -14,9 +14,9 @@ __H__
 #include "XSUB.h"
 #include "KinoSearchUtilMemManager.h"
 
-typedef struct token Token;
+typedef struct Token Token;
 
-struct token {
+struct Token {
     char   *text;
     STRLEN  len;
     I32     start_offset;
@@ -110,7 +110,7 @@ Copyright 2006-2007 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.162.
+See L<KinoSearch|KinoSearch> version 0.163.
 
 =cut
 
