@@ -61,8 +61,9 @@ sub serve {
                 my $client_sock = $main_sock->accept;
 
                 # verify password
-                chomp( my $pass = <$client_sock> );
-                if ( $pass eq $self->{password} ) {
+                my $pass = <$client_sock>;
+                chomp($pass) if defined $pass;
+                if ( defined($pass) && $pass eq $self->{password} ) {
                     $read_set->add($client_sock);
                     print $client_sock "accepted\n";
                 }
@@ -223,7 +224,7 @@ Copyright 2006-2007 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.162.
+See L<KinoSearch|KinoSearch> version 0.163.
 
 =cut
 
