@@ -21,10 +21,10 @@ use KinoSearch::Store::FSInvIndex;
 use KinoSearch::Analysis::Tokenizer;
 use KinoSearch::Analysis::PolyAnalyzer;
 
-use File::Spec::Functions qw( catdir catfile tmpdir );
+use File::Spec::Functions qw( catdir catfile curdir );
 use File::Path qw( rmtree );
 
-my $working_dir = catfile( tmpdir(), 'kinosearch_test' );
+my $working_dir = catfile( curdir(), 'kinosearch_test' );
 
 # Return a directory within the system's temp directory where we will put all
 # testing scratch files.
@@ -37,10 +37,7 @@ sub create_working_dir {
 # Verify that this user owns the working dir, then zap it.  Returns true upon
 # success.
 sub remove_working_dir {
-    my $mode = (stat $working_dir)[2];
     return unless -d $working_dir;
-    $mode &= 07777;
-    return unless $mode == 0700;
     rmtree $working_dir;
     return 1;
 }
